#ifndef SEEKSLIDER_H
#define SEEKSLIDER_H

#include <QtWidgets>

class SeekSlider : public QSlider {

    Q_OBJECT

public:
    SeekSlider(QWidget *parent = 0);
    
};

#endif // SEEKSLIDER_H
